@@ -31,11 +31,11 @@ describe 'aodh' do
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :kombu_compression               => '<SERVICE DEFAULT>',
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -45,6 +45,7 @@ describe 'aodh' do
           :rabbit_retry_interval           => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
           :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
@@ -64,6 +65,7 @@ describe 'aodh' do
 
       it 'configures other parameters' do
         is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('DEFAULT/enable_evaluation_results_metrics').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_oslo__concurrency('aodh_config').with(
           :lock_path => '<SERVICE DEFAULT>'
         )
@@ -86,10 +88,10 @@ describe 'aodh' do
           :rabbit_use_ssl                     => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :kombu_reconnect_delay              => '5.0',
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => true,
           :kombu_compression                  => 'gzip',
           :kombu_ssl_ca_certs                 => '/etc/ca.cert',
           :kombu_ssl_certfile                 => '/etc/certfile',
@@ -98,6 +100,7 @@ describe 'aodh' do
           :rabbit_ha_queues                   => true,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
@@ -111,7 +114,8 @@ describe 'aodh' do
           :notification_topics                => 'openstack',
           :notification_retry                 => 10,
           :package_ensure                     => '2012.1.1-15.el6',
-          :alarm_history_time_to_live         => '604800',
+          :alarm_history_time_to_live         => 604800,
+          :enable_evaluation_results_metrics  => false,
           :lock_path                          => '/var/lock/aodh',
         }
       end
@@ -127,10 +131,10 @@ describe 'aodh' do
           :rabbit_use_ssl                  => true,
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
-          :heartbeat_in_pthread            => true,
           :rabbit_qos_prefetch_count       => 0,
           :kombu_reconnect_delay           => '5.0',
           :amqp_durable_queues             => true,
+          :amqp_auto_delete                => true,
           :kombu_compression               => 'gzip',
           :kombu_ssl_ca_certs              => '/etc/ca.cert',
           :kombu_ssl_certfile              => '/etc/certfile',
@@ -139,6 +143,7 @@ describe 'aodh' do
           :rabbit_ha_queues                => true,
           :rabbit_quorum_queue             => true,
           :rabbit_transient_quorum_queue   => true,
+          :rabbit_transient_queues_ttl     => 60,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
@@ -157,7 +162,8 @@ describe 'aodh' do
       end
 
       it 'configures other parameters' do
-        is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value('604800')
+        is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value(604800)
+        is_expected.to contain_aodh_config('DEFAULT/enable_evaluation_results_metrics').with_value(false)
         is_expected.to contain_oslo__concurrency('aodh_config').with(
           :lock_path => '/var/lock/aodh'
         )
