@@ -27,6 +27,7 @@ describe 'aodh::wsgi::apache' do
         :access_log_pipe             => nil,
         :access_log_syslog           => nil,
         :access_log_format           => nil,
+        :access_log_env_var          => nil,
         :error_log_file              => nil,
         :error_log_pipe              => nil,
         :error_log_syslog            => nil,
@@ -81,16 +82,18 @@ describe 'aodh::wsgi::apache' do
     context 'with custom access logging' do
       let :params do
         {
-          :access_log_format => 'foo',
-          :access_log_syslog => 'syslog:local0',
-          :error_log_syslog  => 'syslog:local1',
+          :access_log_format  => 'foo',
+          :access_log_syslog  => 'syslog:local0',
+          :error_log_syslog   => 'syslog:local1',
+          :access_log_env_var => '!dontlog',
         }
       end
 
       it { should contain_openstacklib__wsgi__apache('aodh_wsgi').with(
-        :access_log_format => params[:access_log_format],
-        :access_log_syslog => params[:access_log_syslog],
-        :error_log_syslog  => params[:error_log_syslog],
+        :access_log_format  => params[:access_log_format],
+        :access_log_syslog  => params[:access_log_syslog],
+        :error_log_syslog   => params[:error_log_syslog],
+        :access_log_env_var => params[:access_log_env_var],
       )}
     end
 
@@ -163,7 +166,7 @@ describe 'aodh::wsgi::apache' do
         when 'RedHat'
           {
             :wsgi_script_path   => '/var/www/cgi-bin/aodh',
-            :wsgi_script_source => '/usr/bin/aodh-api'
+            :wsgi_script_source => '/usr/lib/python3.9/site-packages/aodh/wsgi/api.py',
           }
 
         end
